NetworkConnectivityBloc class

A BLoC (Business Logic Component) that monitors network connectivity changes.

This BLoC listens to changes in network connectivity using the Connectivity package and emits corresponding events based on the connectivity status.

Constructors

NetworkConnectivityBloc()
Initializes the NetworkConnectivityBloc with an initial state of NetworkConnectivityInitial.

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether the bloc is closed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state NetworkConnectivityState
The current state.
no setterinherited
stream Stream<NetworkConnectivityState>
The current stream of states.
no setterinherited
streamSubscription StreamSubscription?
Stream subscription to monitor connectivity changes.
getter/setter pair

Methods

add(NetworkConnectivityEvent event) → void
Notifies the Bloc of a new event which triggers all corresponding EventHandler instances.
inherited
addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
close() Future<void>
Overrides the close method to cancel the stream subscription before closing the BLoC.
emit(NetworkConnectivityState state) → void
emit is only for internal use and should never be called directly outside of tests. The Emitter instance provided to each EventHandler should be used instead.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on<E extends Event>(EventHandler<E, NetworkConnectivityState> handler, {EventTransformer<E>? transformer}) → void
Register event handler for an event of type E. There should only ever be one event handler per event type E.
inherited
onChange(Change<NetworkConnectivityState> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
onEvent(NetworkConnectivityEvent event) → void
Called whenever an event is added to the Bloc. A great spot to add logging/analytics at the individual Bloc level.
inherited
onTransition(Transition<NetworkConnectivityEvent, NetworkConnectivityState> transition) → void
Called whenever a transition occurs with the given transition. A transition occurs when a new event is added and a new state is emitted from a corresponding EventHandler.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited